#$PATHTO=/project/cmcwhite/github

# Record of steps to calculate features for feature_matrix
# Also for building feature matrix


##### Standard features (pearsonR, spearmanR, euclidean distance, braycurtis, xcorr
# Calculate features
# Copy desired elution matrices from protein_identification/identified_elutions/ to features/elutions_and_features


# In top level: 
# This will concatenate elutions from same species and phylogenetic level
# Also will format files for hypergeometric features
Rscript scripts/assemble_elutions_plant.R

# In features/elutions_and_features
# Most run fine with 100 iterations. Added fewer iterations for larger features that seem to not be finishing
# Fix absolute path in COMMANDS file to location of github repo marcottelab:protein_complex_maps
cat ../../records/correlations_COMMANDS.sh | parallel -j20


# Fix absolute path in COMMANDS file
cat ../../records/alphabetize_COMMANDS.sh | parallel -j20


# In directory features/elutions_and_features/single_experiments/
# Get only rows with pearsonR over 0.3
# Copy all *pearson.feat.ordered from single experiments (no species concatenations) to single_experiments, can delete after
# Next time, have pattern in filename that distinguishes single experiments from concatentations
parallel -j20 "awk -F',' \'$3 > 0.3 {print \$1, \$2, FILENAME}' {} > {}.filt03" ::: *pearson*feat.ordered
cat *filt03 > over0.3_spec.txt

# In directory features/elutions_and_features/single_experiments/
# Get list of edges that have at least PearsonR over 0.3 in at least 3 experiments, in at least 2 species
# output called pairs_over03pearson_in3exp_in2species.txt
Rscript ../../../scripts/multi_exp.R

# In directory features/elutions_and_features
# Move unscaled euclidean + braycurtis to features_elutions_and_features/unscaled/
# For these features, 0 is best score. Need to be rescaled so 0 is worst score
mv *euclidean* unscaled/
mv *braycurtis* unscaled/

# From features/elutions_and_features/unscaled
# Filter down to just pairs that fit the over 0.3-in at least 3 exps-2 species filter
parallel -j20 "python $PATHTO/protein_complex_maps/protein_complex_maps/features/normalize_features.py --input_feature_matrix {} --output rescale_{} --features euclidean --sep ',' --inverse --global_preset --min 0" ::: *euclidean*feat.ordered

parallel -j20 "python $PATHTO/protein_complex_maps/protein_complex_maps/features/normalize_features.py --input_feature_matrix {} --output rescale_{} --features braycurtis --sep ',' --inverse --global_preset --min 0 " ::: *braycurtis*feat.ordered

# Move rescaled back up to features/elutions_and_features
mv rescale* ../

# From features/elutions_and_features
parallel -j30 "grep -Ff single_experiments/pairs_over03pearson_in3exp_in2species.txt {} > ../featmat_features/{}.over03_3exp_2spec" ::: *ordered


##### Hypergeometric features

# In directory features/hypergeo_elutions
# Fix absolute path in COMMANDS file
cat ../../records/hypergeometric_COMMANDS.sh | parallel -j20

# In directory features/hypergeo_elutions
# Fix absolute path in COMMANDS file
cat ../../records/alphabetize_COMMANDS_hyper.sh | parallel -j20

# In directory features/hypergeo_elutions
# Filter down to just pairs that fit the over 0.3-in at least 3 exps-2 species filter
parallel -j30 "grep -Ff ../elutions_and_features/single_experiments/pairs_over03pearson_in3exp_in2species.txt {} > ../featmat_features/{}.over03_3exp_2spec" ::: *ordered


####### Build feature matrix
# In directory features/featmat_features
bash records/build_plant_feature_matrix.sh

